import {FC, useCallback, useEffect, useState} from "react";
import {View} from "@tarojs/components";
import styles from './list.module.scss'
import Taro, {useReachBottom, useRouter} from "@tarojs/taro";
import {illnessApi} from "@/api/illness";
import Empty from "@/components/empty/empty";

const BrandList: FC = () => {
  const params = useRouter().params as unknown as { id: number }
  const [page, setPage] = useState(1)
  const [brands, setBrands] = useState<any[]>([])
  const [total, setTotal] = useState(0)
  const [fetchDone, setFetchDone] = useState(false)

  useEffect(() => {
    Taro.showLoading({title: '加载中', mask: true})
    getData().then()
  }, [page])

  const getData = useCallback(async () => {
    try {
      const data = await illnessApi.articleInfo(params.id, page, 20)
      setTotal(data.total)
      setBrands([...brands, ...data.list])
    } catch (e) {
    }
    setFetchDone(true)
    Taro.hideLoading()
  }, [page])

  function jump(id: number) {
    Taro.navigateTo({url: '/pages/preview/illness/article/article?id=' + id})
  }


  useReachBottom(useCallback(() => {
    if (brands?.length < total) {
      setPage(page + 1)
    }
  }, [total, brands]))


  return (
    <View style={{display: fetchDone ? 'block' : 'none'}} className='px-2 pt-2 bg-white'>
      {
        brands.length > 0 ?
          brands.map((d, index) => <View key={d.id} className={styles.brands} onClick={() => jump(d.id)}>
            {index + 1} . {d.title}
          </View>)
          : <Empty name='暂无文章'/>
      }
    </View>
  )
}

export default BrandList
